<?php
/***********************************************************
* The main functions file
* Functions for making WP work like I want it to
***********************************************************/

/***********************************************************
* op_all_cats() - Returns an array of available categories
***********************************************************/
function op_all_cats() {
	$all_cats = get_all_category_ids();
	foreach($all_cats as $key => $value) :
		$all_cats[$key] = get_cat_name($all_cats[$key]);
		$all_cats[$key] = str_replace("&#038;", "&", $all_cats[$key]);
		$all_cats[$key] = str_replace("&amp;","&", $all_cats[$key]);
	endforeach;
	$all_cats['none'] = false;
	return $all_cats;
}

/***********************************************************
* op_all_cat_slugs() - Returns an array of available category slugs
* @since 1.2
***********************************************************/
function op_all_cat_slugs() {
	$cats = get_categories("hierarchical=0");
	foreach($cats as $key) :
		$all_cats[] = $key->category_nicename;
	endforeach;
	$all_cats['none'] = false;
	return $all_cats;
}

/***********************************************************
* op_all_tags() - Returns an array of the available tags (slugs)
* @since 1.1 - 1.2
***********************************************************/
function op_all_tags() {
	$all_tags = wp_tag_cloud('number=0&format=array');
	foreach($all_tags as $key => $value) :
		$value = strip_tags(stripslashes($value));
		$value = strtolower($value);
		$value = str_replace("&nbsp;", "-", $value);
		$all_tags[$key] = $value;
	endforeach;
	$all_tags['none'] = false;
	return $all_tags;
}

/***********************************************************
* op_all_tag_names() - Returns an array of the available tags names
***********************************************************/
function op_all_tag_names() {
	$all_tags = wp_tag_cloud('number=0&format=array');
	foreach($all_tags as $key => $value) :
		$value = strip_tags(stripslashes($value));
		$value = str_replace("&nbsp;", " ", $value);
		$all_tags[$key] = $value;
	endforeach;
	$all_tags['none'] = false;
	return $all_tags;
}

/***********************************************************
* op_all_authors() - Returns an array of the available authors
***********************************************************/
function op_all_authors() {
	global $wpdb, $table_prefix;
	$order = 'user_nicename';
	$user_ids = $wpdb->get_col("SELECT ID FROM $wpdb->users ORDER BY $order");
	foreach($user_ids as $user_id) :
		$user = get_userdata($user_id);
		$level = $table_prefix . 'user_level';
		$user->user_level = $user->$level;
		if($user->user_level > 0) $all_authors[$user_id] = $user->user_login;
	endforeach;
	$all_authors['none'] = false;
	return $all_authors;
}

/***********************************************************
* op_all_authors_ids() - Returns an array of the available author IDs
***********************************************************/
function op_all_authors_ids() {
	global $wpdb, $table_prefix;
	$order = 'user_nicename';
	$user_ids = $wpdb->get_col("SELECT ID FROM $wpdb->users ORDER BY $order");
	foreach($user_ids as $user_id) :
		$user = get_userdata($user_id);
		$level = $table_prefix . 'user_level';
		$user->user_level = $user->$level;
		if($user->user_level > 0) $all_authors[$user_id] = $user->ID;
	endforeach;
	$all_authors['none'] = false;
	return $all_authors;
}

/***********************************************************
* op_author_id() - Returns author ID by nicename
* @since 1.1 - 1.2
***********************************************************/
function op_author_id($author_name) {
	//$author_name = str_replace("-", " ", $author_name); 
	$curauth = get_userdatabylogin($author_name);
	$author_id = $curauth->ID;
	return $author_id;
}

/***********************************************************
* op_author_nicename() - Returns author nicename
* @since 1.1 - 1.2
***********************************************************/
function op_author_nicename($author_name) {
	$curauth = get_userdatabylogin($author_name);
	$nicer = $curauth->user_nicename;
	return $nicer;
}

/***********************************************************
* op_author_display_name() - Returns author display name by nicename
* @since 1.1 - 1.2
***********************************************************/
function op_author_display_name($author_name) {
	//$author_name = str_replace("-", " ", $author_name);
	$curauth = get_userdatabylogin($author_name);
	$display = $curauth->display_name;
	return $display;
}

/***********************************************************
* op_author_cloud() - Returns a cloud of authors
* @since 1.2
***********************************************************/
function op_author_cloud() {
	$author_cloud = op_all_authors_ids();
	foreach($author_cloud as $author) :
		$curauth = get_userdata($author);
		$user_ids[] = $curauth->ID;
		$user_nicenames[] = $curauth->user_nicename;
		$user_name = $curauth->display_name;
		$count = get_usernumposts($curauth->ID);
		if($count >= 0) $counts[$user_name] = $count;
	endforeach;

	$dist = max($counts) - min($counts);
	if($dist <= 0) $dist = 1;
	$font = $dist / 10;
	$i = 0;

	foreach($counts as $authname => $count) :
		$curauth = get_userdata($user_ids[$i]);
		$link = get_author_link(0, $curauth->ID, $curauth->user_nicename);
		echo "\n<a href=\"$link\" title=\"$count "; _e('posts by','options'); echo " $authname\" style=\"font-size:".(10 + ceil($count/$font))."px\">$authname</a> ";
		$i++;
	endforeach;
}

/***********************************************************
* op_category_cloud() - Returns a cloud of categories
* @since 1.2
***********************************************************/
function op_category_cloud() {
	$cat_cloud = get_categories("hierarchical=0");
	foreach($cat_cloud as $cat) :
		$cat_link = get_category_link($cat->cat_ID);
		$cat_name = $cat->cat_name;
		$count = $cat->category_count;
		if($count >= 0) {
			$counts[$cat_name] = $count;
			$cat_links[$cat_name] = $cat_link;
		}
	endforeach;

	$dist = max($counts) - min($counts); 
	if($dist <= 0) $dist = 1;
	$font = $dist / 10;

	foreach($counts as $cat_name => $count) :
		$link = $cat_links[$cat_name];
		echo "\n<a href=\"$link\" title=\"$count "; _e('posts filed under','options'); echo " $cat_name\" style=\"font-size:".(10 + ceil($count/$font))."px\">$cat_name</a> ";
	endforeach;
}
?>